@@ -1,39 +1,21 @@
 /* -*- C++ -*-
+    This file implements the WeaverImpl class.
 
-This file implements the WeaverImpl class.
+    SPDX-FileCopyrightText: 2005-2013 Mirko Boehm <mirko@kde.org>
 
-$ Author: Mirko Boehm $
-$ Copyright: (C) 2005-2013 Mirko Boehm $
-$ Contact: mirko@kde.org
-http://www.kde.org
-http://creative-destruction.me $
-
-   This library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
-
-$Id: WeaverImpl.cpp 30 2005-08-16 16:16:04Z mirko $
+    SPDX-License-Identifier: LGPL-2.0-or-later
 
+    $Id: WeaverImpl.cpp 30 2005-08-16 16:16:04Z mirko $
 */
 
 #include "weaver.h"
 
-#include <QtCore/QCoreApplication>
-#include <QtCore/QObject>
-#include <QtCore/QMutex>
-#include <QtCore/QDebug>
-
+#include <QCoreApplication>
+#include <QMutex>
+#include <QDebug>
+#if QT_VERSION >= QT_VERSION_CHECK(5, 15, 0)
+#include <QDeadlineTimer>
+#endif
 #include "job.h"
 #include "managedjobpointer.h"
 #include "state.h"
@@ -224,7 +206,7 @@ void Weaver::enqueue_p(const QVector<JobPointer> &jobs)
     if (jobs.isEmpty()) {
         return;
     }
-    Q_FOREACH (const JobPointer &job, jobs) {
+    for (const JobPointer &job : jobs) {
         if (job) {
             Q_ASSERT(job->status() == Job::Status_New);
             adjustInventory(jobs.size());
@@ -307,7 +289,11 @@ void Weaver::finish_p()
     while (!isIdle_p()) {
         Q_ASSERT_X(state()->stateId() == WorkingHard, Q_FUNC_INFO, qPrintable(state()->stateName()));
         TWDEBUG(2, "WeaverImpl::finish: not done, waiting.\n");
+#if QT_VERSION < QT_VERSION_CHECK(5, 15, 0)
         if (d()->jobFinished.wait(d()->mutex, MaxWaitMilliSeconds) == false) {
+#else
+        if (d()->jobFinished.wait(d()->mutex, QDeadlineTimer(MaxWaitMilliSeconds)) == false) {
+#endif
             TWDEBUG(2, "WeaverImpl::finish: wait timed out, %i jobs left, waking threads.\n", queueLength_p());
             reschedule();
         }
